==> nextcloud-14.0.13.zip: nextcloud/apps/files/l10n/sl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Storage invalid" : "Določen prostor ni veljaven",
    "Unknown error" : "Neznana napaka",
    "All files" : "Vse datoteke",
    "Recent" : "Nedavno",
    "Favorites" : "Priljubljene",
    "File could not be found" : "Datoteke ni mogoče najti",
    "Move or copy" : "Premakni ali kopiraj",
    "Download" : "Prejmi",
    "Delete" : "Izbriši",
    "Home" : "Domači naslov",
    "Close" : "Zapri",
    "Could not create folder \"{dir}\"" : "Ni mogoče ustvariti mape \"{dir}\"",
    "Upload cancelled." : "Pošiljanje je preklicano.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati {filename}, saj je to mapa, ali pa je velikost datoteke 0 bajtov.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je le {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa \"{dir}\" ne obstaja več",
    "Not enough free space" : "Ni dovolj prostora",
    "Uploading …" : "Poteka pošiljanje ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov, statusna koda {status}",
    "Actions" : "Dejanja",
    "Rename" : "Preimenuj",
    "Copy" : "Kopiraj",
    "Disconnect storage" : "Odklopi shrambo",
    "Unshare" : "Prekini souporabo",
    "Could not load info for file \"{file}\"" : "Ni bilo mogoče naložiti podatke za datoteko \"{file}\"",
    "Files" : "Datoteke",
    "Details" : "Podrobnosti",
    "Select" : "Izberi",
    "Pending" : "V čakanju ...",
    "Unable to determine date" : "Ni mogoče določiti datuma",
    "This operation is forbidden" : "To dejanje ni dovoljeno!",
    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
    "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
    "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja",
    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
    "{newName} already exists" : "{newName} že obstaja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ni mogoče preimenovati \"{fileName}\", ker datoteka ne obstaja več",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberite drugo ime ali drugo mapo.",
    "Could not rename \"{fileName}\"" : "Ni mogoče preimenovati \"{fileName}\"",
    "Could not create file \"{file}\"" : "Ni mogoče ustvariti datoteke \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Ni mogoče ustvariti datoteke \"{file}\", ker že obstaja",
    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape \"{dir}\", ker že obstaja",
    "Error deleting file \"{fileName}\"." : "Napaka brisanja datoteke \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ni rezultatov iskanja v drugih mapah {tag}{filter}{endtag}",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datoteke"],
    "{dirs} and {files}" : "{dirs} in {files}",
    "_including %n hidden_::_including %n hidden_" : ["Vključujoč %n skrit","Vključujoč %n skrita","Vključujoč %n skritih","Vključujoč %n skritih"],
    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje in ustvarjanje datotek na tem mestu.",
    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
    "New" : "Novo",
    "{used} of {quota} used" : "{used} od {quota} uporabljeno",
    "{used} used" : "{used} uporabljeno",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ni dovoljena vrsta datoteke",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Shramba uporabnika {owner} je polna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)" : "Prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom '{filter}'","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
    "View in folder" : "Pokaži v mapi",
    "Copied!" : "Kopirano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
    "Path" : "Pot",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Favorited" : "Označeno kot priljubljeno",
    "Favorite" : "Priljubljene",
    "New folder" : "Nova mapa",
    "Upload file" : "Pošlji datoteko",
    "Not favorited" : "Ni priljubljeno",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
    "Added to favorites" : "Dodano med priljubljene",
    "Removed from favorites" : "Odstranjeno iz priljubljenih",
    "You added {file} to your favorites" : "Med priljubljene je dodana je datoteka {file}",
    "You removed {file} from your favorites" : "Odstranili ste {file} od priljubljenih",
    "File changes" : "Sprememba datoteke",
    "Created by {user}" : "Ustvarjeno od {user}",
    "Changed by {user}" : "Spremenjeno od {user}",
    "Deleted by {user}" : "Izbrisano od {user}",
    "Restored by {user}" : "Obnovljeno od {user}",
    "Renamed by {user}" : "Preimenovano od {user}",
    "Moved by {user}" : "Premaknjeno od {user}",
    "\"remote user\"" : "\"oddaljeni uporabnik\"",
    "You created {file}" : "Ustvarite datoteko {file}",
    "You created an encrypted file in {file}" : "Ustvarjena je šifrirana datoteka v {file}",
    "{user} created {file}" : "{user} ustvari datoteko {file}",
    "{user} created an encrypted file in {file}" : "{user} ustvari šifrirano datoteko {file}",
    "{file} was created in a public folder" : "{file} ustvarjena je bila v javni mapi",
    "You changed {file}" : "Spremenite datoteko {file}",
    "You changed an encrypted file in {file}" : "Spremenite šifrirano datoteko v {file}",
    "{user} changed {file}" : "{user} spremenil/a {file}",
    "You deleted {file}" : "Izbrišete datoteko {file}",
    "{user} deleted {file}" : "{user} izbriše datoteko {file}",
    "You restored {file}" : "Obnovite datoteko {file}",
    "{user} restored {file}" : "{user} obnovi datoteko {file}",
    "You renamed {oldfile} to {newfile}" : "Preimenujete {oldfile} v {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} preimenuje {oldfile} v {newfile}",
    "You moved {oldfile} to {newfile}" : "Premaknete {oldfile} v {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} premakne {oldfile} v {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila ali dodana ali umaknjena iz <strong>priljubljenih</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datoteka ali mapa je bila <strong>spremenjena</strong> ali <strong>preimenovana</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ali mapa je bila <strong>ustvarjena</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je bila <strong>izbrisana</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ali mapa je bila <strong>obnovljena</strong>",
    "Unlimited" : "Neomejeno",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "%s used" : "%s uporabljeno",
    "Settings" : "Nastavitve",
    "Show hidden files" : "Pokaži skrite datoteke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Naslov omogoča dostop do datotek prek <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">WebDAV</a>.",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "No favorites yet" : "Še ni priljubljena",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
    "Tags" : "Oznake",
    "Deleted files" : "Izbrisane datoteke",
    "Shares" : "Souporaba",
    "Shared with others" : "V skupni rabi z ostalimi",
    "Shared with you" : "V skupni rabi z vami",
    "Shared by link" : "Deljeno s povezavo",
    "Deleted shares" : "Izbrisane povezave za souporabo",
    "Text file" : "Besedilna datoteka",
    "New text file.txt" : "Nova datoteka.txt",
    "Target folder" : "Ciljna mapa",
    "File handling" : "Upravljanje z datotekami",
    "Maximum upload size" : "Največja velikost za pošiljanje",
    "max. possible: " : "največ mogoče:",
    "Save" : "Shrani",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Uveljavljanje sprememb prek PHP-FPM lahko traja tudi 5  minut.",
    "Missing permissions to edit from here." : "Ni ustreznih dovoljenj za urejanje na tej ravni.",
    "%s of %s used" : "%s od %s uporabljeno",
    "Cancel upload" : "Prekliči pošiljanje"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-15.0.3.zip: nextcloud/apps/files/l10n/sl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Storage invalid" : "Določen prostor ni veljaven",
    "Unknown error" : "Neznana napaka",
    "All files" : "Vse datoteke",
    "Recent" : "Nedavno",
    "Favorites" : "Priljubljene",
    "File could not be found" : "Datoteke ni mogoče najti",
    "Move or copy" : "Premakni ali kopiraj",
    "Download" : "Prejmi",
    "Delete" : "Izbriši",
    "Home" : "Domači naslov",
    "Close" : "Zapri",
    "Could not create folder \"{dir}\"" : "Ni mogoče ustvariti mape \"{dir}\"",
    "Upload cancelled." : "Pošiljanje je preklicano.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati datoteke {filename}, saj je to ali mapa ali pa je velikost datoteke 0 bajtov.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Na voljo ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je je {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa \"{dir}\" ne obstaja več",
    "Not enough free space" : "Ni dovolj prostora",
    "Uploading …" : "Poteka pošiljanje ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov, statusna koda {status}",
    "Actions" : "Dejanja",
    "Rename" : "Preimenuj",
    "Copy" : "Kopiraj",
    "Disconnect storage" : "Odklopi shrambo",
    "Unshare" : "Prekini souporabo",
    "Could not load info for file \"{file}\"" : "Ni bilo mogoče naložiti podatke za datoteko \"{file}\"",
    "Files" : "Datoteke",
    "Details" : "Podrobnosti",
    "Select" : "Izberi",
    "Pending" : "V čakanju ...",
    "Unable to determine date" : "Ni mogoče določiti datuma",
    "This operation is forbidden" : "To dejanje ni dovoljeno!",
    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
    "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
    "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja",
    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
    "{newName} already exists" : "{newName} že obstaja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ni mogoče preimenovati \"{fileName}\", ker datoteka ne obstaja več",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberite drugo ime ali drugo mapo.",
    "Could not rename \"{fileName}\"" : "Ni mogoče preimenovati \"{fileName}\"",
    "Could not create file \"{file}\"" : "Ni mogoče ustvariti datoteke \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Ni mogoče ustvariti datoteke \"{file}\", ker že obstaja",
    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape \"{dir}\", ker že obstaja",
    "Error deleting file \"{fileName}\"." : "Napaka brisanja datoteke \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ni rezultatov iskanja v drugih mapah {tag}{filter}{endtag}",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datoteke"],
    "{dirs} and {files}" : "{dirs} in {files}",
    "_including %n hidden_::_including %n hidden_" : ["Vključujoč %n skrit","Vključujoč %n skrita","Vključujoč %n skritih","Vključujoč %n skritih"],
    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje ali ustvarjanje datotek na tem mestu.",
    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Posodabljanje %n datotek"],
    "New" : "Novo",
    "{used} of {quota} used" : "{used} od {quota} uporabljeno",
    "{used} used" : "{used} uporabljeno",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ni dovoljena vrsta datoteke",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Shramba uporabnika {owner} je polna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)" : "Prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom '{filter}'","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
    "View in folder" : "Pokaži v mapi",
    "Copied!" : "Kopirano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
    "Path" : "Pot",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Favorited" : "Označeno kot priljubljeno",
    "Favorite" : "Priljubljene",
    "New folder" : "Nova mapa",
    "Upload file" : "Naloži datoteko",
    "Not favorited" : "Ni priljubljeno",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
    "Added to favorites" : "Dodano med priljubljene",
    "Removed from favorites" : "Odstranjeno iz priljubljenih",
    "You added {file} to your favorites" : "Med priljubljene je dodana je datoteka {file}",
    "You removed {file} from your favorites" : "Odstranili ste {file} od priljubljenih",
    "File changes" : "Sprememba datoteke",
    "Created by {user}" : "Ustvarjeno od {user}",
    "Changed by {user}" : "Spremenjeno od {user}",
    "Deleted by {user}" : "Izbrisano od {user}",
    "Restored by {user}" : "Obnovljeno od {user}",
    "Renamed by {user}" : "Preimenovano od {user}",
    "Moved by {user}" : "Premaknjeno od {user}",
    "\"remote user\"" : "\"oddaljeni uporabnik\"",
    "You created {file}" : "Ustvaril(a) si {file}",
    "You created an encrypted file in {file}" : "Ustvarjena je šifrirana datoteka v {file}",
    "{user} created {file}" : "{user} ustvaril(a) {file}",
    "{user} created an encrypted file in {file}" : "{user} ustvaril(a) kodirano datoteko {file}",
    "{file} was created in a public folder" : "{file} ustvarjena je bila v javni mapi",
    "You changed {file}" : "Spremenil(a) si {file}",
    "You changed an encrypted file in {file}" : "Spremenil(a) si kodirano datoteko v {file}",
    "{user} changed {file}" : "{user} spremenil/a {file}",
    "You deleted {file}" : "Izbrisal(a) si {file}",
    "{user} deleted {file}" : "{user} izbrisal(a) {file}",
    "You restored {file}" : "Obnovil(a) si {file}",
    "{user} restored {file}" : "{user} obnovil(a) {file}",
    "You renamed {oldfile} to {newfile}" : "Preimenoval(a) si {oldfile} v {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} preimenoval(a) {oldfile} v {newfile}",
    "You moved {oldfile} to {newfile}" : "Premaknil(a) si {oldfile} v {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} premaknil(a) {oldfile} v {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila ali dodana ali umaknjena iz <strong>priljubljenih</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datoteka ali mapa je bila <strong>spremenjena</strong> ali <strong>preimenovana</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ali mapa je <strong>ustvarjena</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je bila <strong>izbrisana</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>",
    "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
    "Unlimited" : "Neomejeno",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "File handling" : "Upravljanje z datotekami",
    "Maximum upload size" : "Največja velikost za pošiljanja",
    "max. possible: " : "največ mogoče:",
    "Save" : "Shrani",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Uveljavljanje sprememb prek PHP-FPM lahko traja tudi 5  minut.",
    "Missing permissions to edit from here." : "Ni ustreznih dovoljenj za urejanje na tej ravni.",
    "%s of %s used" : "%s od %s uporabljeno",
    "%s used" : "%s uporabljeno",
    "Settings" : "Nastavitve",
    "Show hidden files" : "Pokaži skrite datoteke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Naslov omogoča dostop do datotek prek <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">WebDAV</a>.",
    "Cancel upload" : "Prekliči pošiljanje",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino ali pa omogočite usklajevanje z napravami!",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračenje omejitve velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "No favorites yet" : "Še ni priljubljena",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
    "Tags" : "Oznake",
    "Deleted files" : "Izbrisane datoteke",
    "Shares" : "Souporaba",
    "Shared with others" : "V skupni rabi z ostalimi",
    "Shared with you" : "V skupni rabi z vami",
    "Shared by link" : "Deljeno s povezavo",
    "Deleted shares" : "Izbrisane povezave za souporabo",
    "Text file" : "Besedilna datoteka",
    "New text file.txt" : "Nova datoteka.txt",
    "Target folder" : "Ciljna mapa"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
